@@ -693,10 +693,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adres</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Nuwe ontvang adres</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Nuwe stuur adres</translation>
@@ -713,10 +709,6 @@
         <source>The entered address "%1" is not a valid Litecoin address.</source>
         <translation>Die ingevoerde adres "%1" is nie 'n geldige Litecoin adres nie.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Die ingevoerde adres "%1" is reeds in die adres boek.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Kon beursie nie oopsluit nie.</translation>
@@ -767,42 +759,6 @@
         <source>Command-line options</source>
         <translation>Opdrag lyn opsies</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Gebruik:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>opdrag lyn opsies</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>Gebruikerkoppelvlakopsies:</translation>
-    </message>
-    <message>
-        <source>Choose data directory on startup (default: %u)</source>
-        <translation>Kies data gids by aanvang (standaard: %u)</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Stel taal, byvoorbeeld "de_DE" (standaard: stelsel lokaal)</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Begin geminimeer</translation>
-    </message>
-    <message>
-        <source>Set SSL root certificates for payment request (default: -system-)</source>
-        <translation>Stel SSL-wortelsertifikate vir betaling versoek (standaard: -stelsel-)</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>Wys spatskerm tydens opstart (standaard: %u)</translation>
-    </message>
-    <message>
-        <source>Reset all settings changed in the GUI</source>
-        <translation>Alle instellings wat in die grafiese gebruikerkoppelvlak gewysig is, terugstel</translation>
-    </message>
 </context>
 <context>
     <name>Intro</name>
@@ -1474,6 +1430,10 @@
         <source>Message</source>
         <translation>Boodskap</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Beursie</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1632,6 +1592,10 @@
         <source>%1 to %2</source>
         <translation>%1 tot %2</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Transaksie fooi</translation>
+    </message>
     <message>
         <source>Payment request expired.</source>
         <translation>Betalings versoek verstryk.</translation>
@@ -1913,18 +1877,10 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opsies:</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Litecoin Kern</translation>
     </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>Konneksie opsies:</translation>
-    </message>
     <message>
         <source>Error loading %s</source>
         <translation>Fout met laai %s</translation>
@@ -1933,26 +1889,10 @@
         <source>Importing...</source>
         <translation>Besig met invoer...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Beursie opsies:</translation>
-    </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(standaard: %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Inligting</translation>
     </message>
-    <message>
-        <source>Node relay options:</source>
-        <translation>Node aflos opsies:</translation>
-    </message>
-    <message>
-        <source>RPC server options:</source>
-        <translation>RPC bediener opsies:</translation>
-    </message>
     <message>
         <source>Signing transaction failed</source>
         <translation>Teken van transaksie het misluk</translation>
@@ -1977,58 +1917,10 @@
         <source>Warning</source>
         <translation>Waarskuwing</translation>
     </message>
-    <message>
-        <source>Do not keep transactions in the mempool longer than &lt;n&gt; hours (default: %u)</source>
-        <translation>Moenie transaksies vir langer as &lt;n&gt; ure in die geheuepoel hou nie (verstek: %u)</translation>
-    </message>
     <message>
         <source>%s is set very high!</source>
         <translation>%s is baie hoog gestel!</translation>
     </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(standaard: %s)</translation>
-    </message>
-    <message>
-        <source>Listen for JSON-RPC connections on &lt;port&gt; (default: %u or testnet: %u)</source>
-        <translation>Luister vir JSON-RPC konneksies op &lt;port&gt; (verstek: %u of testnet: %u)</translation>
-    </message>
-    <message>
-        <source>Listen for connections on &lt;port&gt; (default: %u or testnet: %u)</source>
-        <translation>Luister vir konneksies op &lt;port&gt; (verstek: %u of testnet: %u)</translation>
-    </message>
-    <message>
-        <source>Maintain at most &lt;n&gt; connections to peers (default: %u)</source>
-        <translation>Handhaaf hoogstens &lt;n&gt; verbindings na portuurs (verstek: %u)</translation>
-    </message>
-    <message>
-        <source>Make the wallet broadcast transactions</source>
-        <translation>Maak dat die beursie transaksies uitsaai</translation>
-    </message>
-    <message>
-        <source>Maximum per-connection receive buffer, &lt;n&gt;*1000 bytes (default: %u)</source>
-        <translation>Maksimum per-konneksie ontvang buffer, &lt;n&gt;*1000 grepe (verstek: %u)</translation>
-    </message>
-    <message>
-        <source>Maximum per-connection send buffer, &lt;n&gt;*1000 bytes (default: %u)</source>
-        <translation>Maksimum per-konneksie stuur buffer, &lt;n&gt;*1000 grepe (verstek: %u)</translation>
-    </message>
-    <message>
-        <source>Prepend debug output with timestamp (default: %u)</source>
-        <translation>Voeg ontfout-uitset met tydstempel by (verstek: %u)</translation>
-    </message>
-    <message>
-        <source>Specify configuration file (default: %s)</source>
-        <translation>Spesifiseer konfigurasie lêer (verstek: %s)</translation>
-    </message>
-    <message>
-        <source>Specify connection timeout in milliseconds (minimum: 1, default: %d)</source>
-        <translation>Spesifiseer konneksie timeout in millisekondes (minimum: 1, verstek: %d)</translation>
-    </message>
-    <message>
-        <source>Specify pid file (default: %s)</source>
-        <translation>Spesifiseer pid lêer (verstek: %s)</translation>
-    </message>
     <message>
         <source>Starting network threads...</source>
         <translation>Begin tans netwerkdrade...</translation>
@@ -2041,10 +1933,6 @@
         <source>This is the transaction fee you will pay if you send a transaction.</source>
         <translation>Dit is die transaksie fooi wat u sal betaal as u 'n transaksie stuur.</translation>
     </message>
-    <message>
-        <source>Threshold for disconnecting misbehaving peers (default: %u)</source>
-        <translation>Drumpel vir die ontkoppel van misdadige portuurs (verstek: %u)</translation>
-    </message>
     <message>
         <source>Transaction amounts must not be negative</source>
         <translation>Transaksies bedrae moet nie negatief wees nie</translation>
@@ -2059,7 +1947,7 @@
     </message>
     <message>
         <source>Unknown network specified in -onlynet: '%s'</source>
-        <translation>Onbekend netwerk gespesifiseer in -onlynet: '%s'</translation>
+        <translation>Onbekende netwerk gespesifiseer in -onlynet: '%s'</translation>
     </message>
     <message>
         <source>Insufficient funds</source>
