@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Изтрий избрания адрес от списъка</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Търсене по адрес или име</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Запишете данните от текущия раздел във файл</translation>
@@ -693,10 +697,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Адрес</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Нов адрес за получаване</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Нов адрес за изпращане</translation>
@@ -713,10 +713,6 @@
         <source>The entered address "%1" is not a valid Litecoin address.</source>
         <translation>"%1" не е валиден Биткоин адрес.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Вече има адрес "%1" в списъка с адреси.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Отключването на портфейла беше неуспешно.</translation>
@@ -767,42 +763,6 @@
         <source>Command-line options</source>
         <translation>Списък с команди</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Използване:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>Списък с налични команди</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>Опции на интерфейс:</translation>
-    </message>
-    <message>
-        <source>Choose data directory on startup (default: %u)</source>
-        <translation>Избери директория за данни при стартирване (по подразбиране: %u)</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Избери език, примерно "de_DE" (по подразбиране: system locale)</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Стартирай минимизиран</translation>
-    </message>
-    <message>
-        <source>Set SSL root certificates for payment request (default: -system-)</source>
-        <translation>Задай SSL root сертификат за молба за изплащане (по подразбиране: -system-)</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>Покажи splash екран при стартирване (по подразбиране %u)</translation>
-    </message>
-    <message>
-        <source>Reset all settings changed in the GUI</source>
-        <translation>Нулиране на всички настройки променени в GUI</translation>
-    </message>
 </context>
 <context>
     <name>Intro</name>
@@ -1518,6 +1478,10 @@
         <source>Message</source>
         <translation>Съобщение</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Портфейл</translation>
+    </message>
     <message>
         <source>Error encoding URI into QR Code.</source>
         <translation>Грешка при създаването на QR Code от URI.</translation>
@@ -1680,14 +1644,14 @@
         <source>Are you sure you want to send?</source>
         <translation>Наистина ли искате да изпратите?</translation>
     </message>
-    <message>
-        <source>added as transaction fee</source>
-        <translation>добавено като такса за транзакция</translation>
-    </message>
     <message>
         <source>or</source>
         <translation>или</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Такса</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Потвърждаване</translation>
@@ -1929,10 +1893,6 @@
         <source>Open until %1</source>
         <translation>Подлежи на промяна до %1</translation>
     </message>
-    <message>
-        <source>%1/offline</source>
-        <translation>%1/офлайн</translation>
-    </message>
     <message>
         <source>%1/unconfirmed</source>
         <translation>%1/непотвърдени</translation>
@@ -1945,10 +1905,6 @@
         <source>Status</source>
         <translation>Статус</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, все още не е изпратено</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Дата</translation>
@@ -2079,10 +2035,6 @@
         <source>Open until %1</source>
         <translation>Подлежи на промяна до %1</translation>
     </message>
-    <message>
-        <source>Offline</source>
-        <translation>Извън линия</translation>
-    </message>
     <message>
         <source>Unconfirmed</source>
         <translation>Непотвърдено</translation>
@@ -2103,10 +2055,6 @@
         <source>Immature (%1 confirmations, will be available after %2)</source>
         <translation>Неплатим (%1 потвърждения, ще бъде платим след %2)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Блокът не е получен от останалите участници и най-вероятно няма да бъде одобрен.</translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>Генерирана, но отхвърлена от мрежата</translation>
@@ -2346,41 +2294,13 @@
         <source>The wallet data was successfully saved to %1.</source>
         <translation>Информацията за портфейла беше успешно запазена в %1.</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Опции:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Определете директория за данните</translation>
-    </message>
-    <message>
-        <source>Connect to a node to retrieve peer addresses, and disconnect</source>
-        <translation>Свържете се към сървър за да можете да извлечете адресите на пиърите след което се разкачете.</translation>
-    </message>
-    <message>
-        <source>Specify your own public address</source>
-        <translation>Въведете Ваш публичен адрес</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Litecoin ядро</translation>
     </message>
-    <message>
-        <source>&lt;category&gt; can be:</source>
-        <translation>&lt;category&gt; може да бъде:</translation>
-    </message>
-    <message>
-        <source>Accept connections from outside (default: 1 if no -proxy or -connect)</source>
-        <translation>Приемайте връзки отвън.(по подразбиране:1 в противен случай -proxy или -connect)</translation>
-    </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>Настройки на връзката:</translation>
-    </message>
     <message>
         <source>Do you want to rebuild the block database now?</source>
         <translation>Желаете ли да пресъздадете базата данни с блокове сега?</translation>
@@ -2405,22 +2325,10 @@
         <source>Verifying blocks...</source>
         <translation>Проверка на блоковете...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Настройки на портфейла:</translation>
-    </message>
-    <message>
-        <source>Connect through SOCKS5 proxy</source>
-        <translation>Свързване чрез SOCKS5  прокси</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
-    <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>Изпрати локализиращата или дебъг информацията към конзолата, вместо файлът debug.log</translation>
-    </message>
     <message>
         <source>This is experimental software.</source>
         <translation>Това е експериментален софтуер.</translation>
@@ -2433,30 +2341,10 @@
         <source>Transaction too large</source>
         <translation>Транзакцията е твърде голяма</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>Потребителско име за JSON-RPC връзките</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>Парола за  JSON-RPC връзките</translation>
-    </message>
-    <message>
-        <source>Specify configuration file (default: %s)</source>
-        <translation>Назовете конфигурационен файл(по подразбиране %s)</translation>
-    </message>
-    <message>
-        <source>Specify connection timeout in milliseconds (minimum: 1, default: %d)</source>
-        <translation>Задайте време на изключване при проблеми със свързването в милисекунди(минимум:1, по подразбиране %d)</translation>
-    </message>
-    <message>
-        <source>Specify pid file (default: %s)</source>
-        <translation>Задайте pid  файл(по подразбиране: %s)</translation>
-    </message>
     <message>
         <source>Starting network threads...</source>
         <translation>Стартиране на мрежовите нишки...</translation>
