@@ -623,10 +623,6 @@
     </context>
 <context>
     <name>HelpMessageDialog</name>
-    <message>
-        <source>Usage:</source>
-        <translation>Cynefod:</translation>
-    </message>
     </context>
 <context>
     <name>Intro</name>
@@ -778,6 +774,10 @@
         <source>Label</source>
         <translation>Label</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Waled</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1037,10 +1037,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opsiynau:</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Craidd Litecoin</translation>
