@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Eliminar la dirección actualmente seleccionada de la lista</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Ingrese dirección o capa a buscar </translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Exportar la información en la tabla actual a un archivo</translation>
@@ -369,15 +373,7 @@
         <source>Command-line options</source>
         <translation>opciones de la Linea de comandos</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Uso:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>Opciones de comando de lineas</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -492,6 +488,10 @@
         <source>Copy &amp;Address</source>
         <translation>&amp;Copiar dirección</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Cartera</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -655,26 +655,14 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opciones:</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>nucleo Litecoin</translation>
     </message>
-    <message>
-        <source>&lt;category&gt; can be:</source>
-        <translation>&lt;categoria&gt; puede ser:</translation>
-    </message>
     <message>
         <source>Verifying blocks...</source>
         <translation>Verificando bloques...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Opciones de cartera:</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Información </translation>
