@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Kustuta märgistatud aadress loetelust</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Otsimiseks sisesta märgis või aadress</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Ekspordi kuvatava vahelehe sisu faili</translation>
@@ -609,10 +613,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Aadress</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Uus vastu võttev aadress</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Uus saatev aadress</translation>
@@ -629,10 +629,6 @@
         <source>The entered address "%1" is not a valid Litecoin address.</source>
         <translation>Sisestatud aadress "%1" ei ole korrektne Litecoin aadress.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Sisestatud aadress "%1" on juba aadressi raamatus.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Rahakoti lahtilukustamine ebaõnnestus.</translation>
@@ -659,23 +655,7 @@
         <source>Command-line options</source>
         <translation>Käsurea valikud</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Kasutus:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>käsurea valikud</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>Kasutajaliidese Suvandid:</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>Käivitamisel kuva laadimisekraani (vaikimisi %u)</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -1174,6 +1154,10 @@
         <source>Message</source>
         <translation>Sõnum</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Rahakott</translation>
+    </message>
     <message>
         <source>Resulting URI too long, try to reduce the text for label / message.</source>
         <translation>URI liiga pikk, proovi vähendada märke / sõnumi pikkust.</translation>
@@ -1328,14 +1312,14 @@
         <source>Are you sure you want to send?</source>
         <translation>Oled kindel, et soovid saata?</translation>
     </message>
-    <message>
-        <source>added as transaction fee</source>
-        <translation>lisatud kui tehingutasu</translation>
-    </message>
     <message>
         <source>or</source>
         <translation>või</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Tehingutasu</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Müntide saatmise kinnitamine</translation>
@@ -1585,10 +1569,6 @@
         <source>Open until %1</source>
         <translation>Avatud kuni %1</translation>
     </message>
-    <message>
-        <source>%1/offline</source>
-        <translation>%1/offline'is</translation>
-    </message>
     <message>
         <source>%1/unconfirmed</source>
         <translation>%1/kinnitamata</translation>
@@ -1601,10 +1581,6 @@
         <source>Status</source>
         <translation>Olek</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, veel esitlemata</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Kuupäev</translation>
@@ -1731,10 +1707,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>Kinnitatud (%1 kinnitust)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Antud klotsi pole saanud ükski osapool ning tõenäoliselt seda ei aktsepteerita!</translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>Loodud, kuid aktsepteerimata</translation>
@@ -1945,54 +1917,14 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Valikud:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Täpsusta andmekataloog</translation>
-    </message>
-    <message>
-        <source>Connect to a node to retrieve peer addresses, and disconnect</source>
-        <translation>Peeri aadressi saamiseks ühendu korraks node'iga</translation>
-    </message>
-    <message>
-        <source>Specify your own public address</source>
-        <translation>Täpsusta enda avalik aadress</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>Luba käsurea ning JSON-RPC käsklusi</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>Tööta taustal ning aktsepteeri käsklusi</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Litecoini tuumik</translation>
     </message>
-    <message>
-        <source>Bind to given address and always listen on it. Use [host]:port notation for IPv6</source>
-        <translation>Määratud aadressiga sidumine ning sellelt kuulamine. IPv6 jaoks kasuta vormingut [host]:port</translation>
-    </message>
-    <message>
-        <source>Execute command when a wallet transaction changes (%s in cmd is replaced by TxID)</source>
-        <translation>Käivita käsklus, kui rahakoti tehing muutub (%s cmd's muudetakse TxID'ks)</translation>
-    </message>
     <message>
         <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
         <translation>See on test-versioon - kasutamine omal riisikol - ära kasuta mining'uks ega kaupmeeste programmides</translation>
     </message>
-    <message>
-        <source>Accept connections from outside (default: 1 if no -proxy or -connect)</source>
-        <translation>Luba välisühendusi (vaikeväärtus: 1 kui puudub -proxy või -connect)</translation>
-    </message>
-    <message>
-        <source>Block creation options:</source>
-        <translation>Blokeeri loomise valikud:</translation>
-    </message>
     <message>
         <source>Corrupted block database detected</source>
         <translation>Tuvastati vigane bloki andmebaas</translation>
@@ -2029,30 +1961,10 @@
         <source>Verifying blocks...</source>
         <translation>Kontrollin blokke...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Rahakoti valikud:</translation>
-    </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(vaikimisi: %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Informatsioon</translation>
     </message>
-    <message>
-        <source>RPC server options:</source>
-        <translation>RPC serveri valikud:</translation>
-    </message>
-    <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>Saada jälitus/debug, debug.log faili asemel, konsooli</translation>
-    </message>
-    <message>
-        <source>Shrink debug.log file on client startup (default: 1 when no -debug)</source>
-        <translation>Kahanda programmi käivitamisel debug.log faili (vaikeväärtus: 1, kui ei ole -debug)</translation>
-    </message>
     <message>
         <source>Signing transaction failed</source>
         <translation>Tehingu allkirjastamine ebaõnnestus</translation>
@@ -2069,30 +1981,10 @@
         <source>Transaction too large</source>
         <translation>Tehing liiga suur</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>JSON-RPC ühenduste kasutajatunnus</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Hoiatus</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>JSON-RPC ühenduste salasõna</translation>
-    </message>
-    <message>
-        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
-        <translation>Käivita käsklus, kui parim plokk muutub (käskluse %s asendatakse ploki hash'iga)</translation>
-    </message>
-    <message>
-        <source>Allow DNS lookups for -addnode, -seednode and -connect</source>
-        <translation>-addnode, -seednode ja -connect tohivad kasutada DNS lookup'i</translation>
-    </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(vaikimisi: %s)</translation>
-    </message>
     <message>
         <source>Unknown network specified in -onlynet: '%s'</source>
         <translation>Kirjeldatud tundmatu võrgustik -onlynet'is: '%s'</translation>
