@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>حذف آدرس منتخب از لیست</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>برای جست‌‌وجو نشانی یا برچسب را وارد کنید</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>صدور داده‌های برگهٔ فعلی به یک پرونده</translation>
@@ -641,10 +645,6 @@
         <source>&amp;Address</source>
         <translation>&amp;نشانی</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>نشانی گیرنده جدید</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>نشانی فرستنده جدید</translation>
@@ -661,15 +661,15 @@
         <source>The entered address "%1" is not a valid Litecoin address.</source>
         <translation>نشانی وارد شده "%1" یک نشانی معتبر Litecoin نیست.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>نشانی وارد شده «%1» در حال حاضر در دفترچه وجود دارد.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>نمی‌توان کیف پول را رمزگشایی کرد.</translation>
     </message>
-    </context>
+    <message>
+        <source>New key generation failed.</source>
+        <translation>تولید کلید جدید ناموفق بود.</translation>
+    </message>
+</context>
 <context>
     <name>FreespaceChecker</name>
     <message>
@@ -711,35 +711,7 @@
         <source>Command-line options</source>
         <translation>گزینه‌های خط‌فرمان</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>استفاده:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>گزینه‌های خط فرمان</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>گزینه‌های رابط کاربری:</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>زبان را تنظیم کنید؛ برای مثال «de_DE» (پیشفرض: زبان سیستم)</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>شروع برنامه به صورت کوچک‌شده</translation>
-    </message>
-    <message>
-        <source>Set SSL root certificates for payment request (default: -system-)</source>
-        <translation>تنظیم گواهی ریشه SSl برای درخواست پرداخت (پیشفرض: -system-)</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>نمایش پنجرهٔ خوشامدگویی در ابتدای اجرای برنامه (پیش‌فرض: %u)</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -1152,6 +1124,10 @@
         <source>Memory Pool</source>
         <translation>استخر حافظه</translation>
     </message>
+    <message>
+        <source>Current number of transactions</source>
+        <translation>تعداد تراکنش های فعلی</translation>
+    </message>
     <message>
         <source>Memory usage</source>
         <translation>مصرف حافظه</translation>
@@ -1303,6 +1279,10 @@
         <source>Copy label</source>
         <translation>کپی برچسب</translation>
     </message>
+    <message>
+        <source>Copy message</source>
+        <translation>کپی پیام</translation>
+    </message>
     <message>
         <source>Copy amount</source>
         <translation>کپی مقدار</translation>
@@ -1330,17 +1310,37 @@
         <source>Label</source>
         <translation>برچسب</translation>
     </message>
+    <message>
+        <source>Message</source>
+        <translation>پیام</translation>
+    </message>
+    <message>
+        <source>Wallet</source>
+        <translation>کیف پول</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
+    <message>
+        <source>Date</source>
+        <translation>تاریخ</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>برچسب</translation>
     </message>
+    <message>
+        <source>Message</source>
+        <translation>پیام</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(بدون برچسب)</translation>
     </message>
+    <message>
+        <source>(no message)</source>
+        <translation>(بدون پیام)</translation>
+    </message>
     </context>
 <context>
     <name>SendCoinsDialog</name>
@@ -1456,6 +1456,14 @@
         <source>Copy change</source>
         <translation>کپی کردن تغییر</translation>
     </message>
+    <message>
+        <source>or</source>
+        <translation>یا</translation>
+    </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>هزینهٔ تراکنش</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(بدون برچسب)</translation>
@@ -1621,20 +1629,84 @@
 </context>
 <context>
     <name>TransactionDesc</name>
+    <message>
+        <source>Status</source>
+        <translation>وضعیت</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>تاریخ</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation>منبع</translation>
+    </message>
+    <message>
+        <source>Generated</source>
+        <translation>تولید شده</translation>
+    </message>
+    <message>
+        <source>From</source>
+        <translation>از</translation>
+    </message>
+    <message>
+        <source>To</source>
+        <translation>به</translation>
+    </message>
+    <message>
+        <source>Credit</source>
+        <translation>اعتبار</translation>
+    </message>
+    <message>
+        <source>Message</source>
+        <translation>پیام</translation>
+    </message>
+    <message>
+        <source>Transaction</source>
+        <translation>تراکنش</translation>
+    </message>
+    <message>
+        <source>Inputs</source>
+        <translation>ورودی ها</translation>
+    </message>
     </context>
 <context>
     <name>TransactionDescDialog</name>
     <message>
         <source>This pane shows a detailed description of the transaction</source>
-        <translation>این پانل شامل توصیف کاملی از جزئیات تراکنش است</translation>
+        <translation>این پنل شامل توصیف کاملی از جزئیات تراکنش است</translation>
     </message>
     </context>
 <context>
     <name>TransactionTableModel</name>
+    <message>
+        <source>Date</source>
+        <translation>تاریخ</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>نوع</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>برچسب</translation>
     </message>
+    <message>
+        <source>Received with</source>
+        <translation>دریافت شد با</translation>
+    </message>
+    <message>
+        <source>Received from</source>
+        <translation>دریافت شد از</translation>
+    </message>
+    <message>
+        <source>Sent to</source>
+        <translation>فرستاده شد به</translation>
+    </message>
+    <message>
+        <source>(n/a)</source>
+        <translation>(نامعلوم)</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(بدون برچسب)</translation>
@@ -1642,6 +1714,38 @@
     </context>
 <context>
     <name>TransactionView</name>
+    <message>
+        <source>All</source>
+        <translation>همه</translation>
+    </message>
+    <message>
+        <source>Today</source>
+        <translation>امروز</translation>
+    </message>
+    <message>
+        <source>This week</source>
+        <translation>این هفته</translation>
+    </message>
+    <message>
+        <source>This month</source>
+        <translation>این ماه</translation>
+    </message>
+    <message>
+        <source>Last month</source>
+        <translation>ماه قبل</translation>
+    </message>
+    <message>
+        <source>This year</source>
+        <translation>امسال</translation>
+    </message>
+    <message>
+        <source>Received with</source>
+        <translation>دریافت شد با</translation>
+    </message>
+    <message>
+        <source>Sent to</source>
+        <translation>فرستاده شد به</translation>
+    </message>
     <message>
         <source>Copy address</source>
         <translation>کپی ادرس</translation>
@@ -1658,10 +1762,30 @@
         <source>Copy transaction ID</source>
         <translation>کپی شناسهٔ تراکنش</translation>
     </message>
+    <message>
+        <source>Edit label</source>
+        <translation>ویرایش برچسب</translation>
+    </message>
+    <message>
+        <source>Show transaction details</source>
+        <translation>نمایش جزئیات تراکنش</translation>
+    </message>
+    <message>
+        <source>Export Transaction History</source>
+        <translation>استخراج تاریخچه تراکنش ها</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>فایل جدا شده با ویرگول(*.csv)</translation>
     </message>
+    <message>
+        <source>Date</source>
+        <translation>تاریخ</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>نوع</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>برچسب</translation>
@@ -1674,7 +1798,11 @@
         <source>Exporting Failed</source>
         <translation>صدور موفق نبود</translation>
     </message>
-    </context>
+    <message>
+        <source>to</source>
+        <translation>به</translation>
+    </message>
+</context>
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
@@ -1693,54 +1821,10 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>گزینه‌ها:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>مشخص کردن دایرکتوری داده‌ها</translation>
-    </message>
-    <message>
-        <source>Connect to a node to retrieve peer addresses, and disconnect</source>
-        <translation>اتصال به یک گره برای دریافت آدرس‌های همتا و قطع اتصال پس از اتمام عملیات</translation>
-    </message>
-    <message>
-        <source>Specify your own public address</source>
-        <translation>آدرس عمومی خود را مشخص کنید</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>پذیرش دستورات خط فرمان و دستورات JSON-RPC</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>اجرا در پشت زمینه به‌صورت یک سرویس و پذیرش دستورات</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation> هسته Litecoin </translation>
     </message>
-    <message>
-        <source>Bind to given address and always listen on it. Use [host]:port notation for IPv6</source>
-        <translation>مقید به نشانی داده شده باشید و همیشه از آن پیروی کنید. از نشانه گذاری استاندار IPv6 به صورت Host]:Port] استفاده کنید.</translation>
-    </message>
-    <message>
-        <source>Execute command when a wallet transaction changes (%s in cmd is replaced by TxID)</source>
-        <translation>هنگامی که یک تراکنش در کیف پولی رخ می دهد، دستور را اجرا کن(%s در دستورات بوسیله ی TxID جایگزین می شود)</translation>
-    </message>
-    <message>
-        <source>Accept connections from outside (default: 1 if no -proxy or -connect)</source>
-        <translation>پذیرش اتصالات از بیرون (پیش فرض:1 بدون پراکسی یا اتصال)</translation>
-    </message>
-    <message>
-        <source>Block creation options:</source>
-        <translation>بستن گزینه ایجاد</translation>
-    </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>گزینه‌های اتصال:</translation>
-    </message>
     <message>
         <source>Copyright (C) %i-%i</source>
         <translation>حق تألیف (C) %i-%i</translation>
@@ -1785,37 +1869,17 @@
         <source>Loading banlist...</source>
         <translation>بارگذاری لیست‌سیاه...</translation>
     </message>
-    <message>
-        <source>Print this help message and exit</source>
-        <translation>چاپ ایت پیام کمک و خروج</translation>
-    </message>
-    <message>
-        <source>Print version and exit</source>
-        <translation>چاپ نسخه و خروج</translation>
-    </message>
     <message>
         <source>Verifying blocks...</source>
         <translation>در حال بازبینی بلوک‌ها...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>گزینه‌های کیف پول:</translation>
-    </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(پیش‌فرض %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>اطلاعات</translation>
     </message>
     <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>اطلاعات ردگیری/اشکال‌زدایی را به جای فایل لاگ اشکال‌زدایی به کنسول بفرستید</translation>
-    </message>
-    <message>
-        <source>Shrink debug.log file on client startup (default: 1 when no -debug)</source>
-        <translation>فایل debug.log  را در startup مشتری کوچک کن (پیش فرض:1 اگر اشکال زدایی روی نداد)</translation>
+        <source>This is experimental software.</source>
+        <translation>این یک نرم افزار آزمایشی است.</translation>
     </message>
     <message>
         <source>Transaction amount too small</source>
@@ -1825,10 +1889,6 @@
         <source>Transaction too large</source>
         <translation>تراکنش بسیار بزرگ است</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>JSON-RPC شناسه برای ارتباطات</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>هشدار</translation>
@@ -1837,22 +1897,6 @@
         <source>Warning: unknown new rules activated (versionbit %i)</source>
         <translation>هشدار: قوانین جدید ناشناخته‌ای فعال شده‌اند (نسخه‌بیت %i)</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>JSON-RPC عبارت عبور برای ارتباطات</translation>
-    </message>
-    <message>
-        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
-        <translation>زمانی که بهترین بلاک تغییر کرد، دستور را اجرا کن (%s در cmd با block hash جایگزین شده است)</translation>
-    </message>
-    <message>
-        <source>Allow DNS lookups for -addnode, -seednode and -connect</source>
-        <translation>به DNS اجازه بده تا برای addnode ، seednode و اتصال جستجو کند</translation>
-    </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(پیش‌فرض %s)</translation>
-    </message>
     <message>
         <source>Unknown network specified in -onlynet: '%s'</source>
         <translation>شبکه مشخص شده غیرقابل شناسایی در onlynet: '%s'</translation>
