@@ -351,10 +351,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adresa</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Adresë e re pritëse</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Adresë e re dërgimi</translation>
@@ -367,10 +363,6 @@
         <source>Edit sending address</source>
         <translation>ndrysho adresën dërguese</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Adresa e dhënë "%1" është e zënë në librin e adresave. </translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Nuk mund të ç'kyçet portofoli.</translation>
@@ -520,6 +512,10 @@
         <source>Label</source>
         <translation>Etiketë</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Portofol</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -655,10 +651,6 @@
         <source>%1 confirmations</source>
         <translation>%1 konfirmimet</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, nuk është transmetuar me sukses deri tani</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Data</translation>
@@ -705,10 +697,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>I/E konfirmuar(%1 konfirmime)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Ky bllok është marrë nga ndonjë nyje dhe ka shumë mundësi të mos pranohet! </translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>I krijuar por i papranuar</translation>
@@ -803,10 +791,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opsionet:</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Berthama Litecoin</translation>
