@@ -580,6 +580,10 @@
         <source>Address</source>
         <translation>முகவரி</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>பணப்பை</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -711,10 +715,6 @@
         <source>Litecoin Core</source>
         <translation>Litecoin மையம்</translation>
     </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(default: %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>தகவல்</translation>
@@ -723,10 +723,6 @@
         <source>Warning</source>
         <translation>எச்சரிக்கை</translation>
     </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(default: %s)</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>தவறு</translation>
