@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>&amp;New</source>
-        <translation>&amp;Mới</translation>
+        <translation>&amp;Tạo mới</translation>
     </message>
     <message>
         <source>Copy the currently selected address to the system clipboard</source>
@@ -61,6 +61,14 @@
         <source>Receiving addresses</source>
         <translation>Địa chỉ nhận</translation>
     </message>
+    <message>
+        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
+        <translation>Đây là các địa chỉ Litecoin để gửi bạn gửi tiền. Trước khi gửi bạn nên kiểm tra lại số tiền bạn muốn gửi và địa chỉ litecoin của người nhận.</translation>
+    </message>
+    <message>
+        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
+        <translation>Đây là các địa chỉ Litecoin để bạn nhận tiền. Với mỗi giao dịch, bạn nên dùng một địa chỉ Litecoin mới để nhận tiền.</translation>
+    </message>
     <message>
         <source>&amp;Copy Address</source>
         <translation>&amp;Chép Địa chỉ</translation>
@@ -119,6 +127,14 @@
         <source>Repeat new passphrase</source>
         <translation>Điền lại passphrase</translation>
     </message>
+    <message>
+        <source>Show password</source>
+        <translation>Hiện mật khẩu</translation>
+    </message>
+    <message>
+        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
+        <translation>Nhập passphrase mới cho Ví của bạn.&lt;br/&gt;Vui long dùng  passphrase gồm&lt;b&gt;ít nhất 10 ký tự bất kỳ &lt;/b&gt;, hoặc &lt;b&gt;ít nhất 8 chữ&lt;/b&gt;.</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Mã hóa ví</translation>
@@ -608,23 +624,7 @@ Ví của bạn chưa được mã hóa.</translation>
         <source>Command-line options</source>
         <translation>&amp;Tùy chọn dòng lệnh</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Mức sử dụng</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>tùy chọn dòng lệnh</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Chọn ngôn ngữ, ví dụ "de_DE" (mặc định: Vị trí hệ thống)</translation>
-    </message>
-    <message>
-        <source>Set SSL root certificates for payment request (default: -system-)</source>
-        <translation>Đặt chứng nhận SSL gốc cho yêu cầu giao dịch (mặc định: -hệ thống-)</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -963,6 +963,10 @@ Ví của bạn chưa được mã hóa.</translation>
         <source>Message</source>
         <translation>Tin nhắn</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Ví</translation>
+    </message>
     <message>
         <source>Error encoding URI into QR Code.</source>
         <translation>Lỗi khi encode từ URI thành QR Code</translation>
@@ -1085,10 +1089,6 @@ Ví của bạn chưa được mã hóa.</translation>
         <source>%1 to %2</source>
         <translation>%1 đến %2</translation>
     </message>
-    <message>
-        <source>Total Amount %1</source>
-        <translation>Tổng cộng %1</translation>
-    </message>
     <message>
         <source>or</source>
         <translation>hoặc</translation>
@@ -1202,18 +1202,10 @@ Ví của bạn chưa được mã hóa.</translation>
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Lựa chọn:</translation>
-    </message>
     <message>
         <source>Litecoin Core</source>
         <translation>Litecoin Core</translation>
     </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(mặc định: %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Thông tin</translation>
@@ -1226,10 +1218,6 @@ Ví của bạn chưa được mã hóa.</translation>
         <source>Warning</source>
         <translation>Chú ý</translation>
     </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(mặc định: %s)</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Không đủ tiền</translation>
